from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TCollection import *
from OCC.Core.OSD import *
from OCC.Core.TColStd import *

#the following typedef cannot be wrapped as is
Message_HArrayOfMsg = NewType('Message_HArrayOfMsg', Any)

class Message_ListOfAlert:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class Message_ListOfMsg:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> Message_Msg: ...
    def Last(self) -> Message_Msg: ...
    def Append(self, theItem: Message_Msg) -> Message_Msg: ...
    def Prepend(self, theItem: Message_Msg) -> Message_Msg: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> Message_Msg: ...
    def SetValue(self, theIndex: int, theValue: Message_Msg) -> None: ...

class Message_SequenceOfPrinters:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Length(self) -> int: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class Message_Status(IntEnum):
	Message_None: int = ...
	Message_Done1: int = ...
	Message_Done2: int = ...
	Message_Done3: int = ...
	Message_Done4: int = ...
	Message_Done5: int = ...
	Message_Done6: int = ...
	Message_Done7: int = ...
	Message_Done8: int = ...
	Message_Done9: int = ...
	Message_Done10: int = ...
	Message_Done11: int = ...
	Message_Done12: int = ...
	Message_Done13: int = ...
	Message_Done14: int = ...
	Message_Done15: int = ...
	Message_Done16: int = ...
	Message_Done17: int = ...
	Message_Done18: int = ...
	Message_Done19: int = ...
	Message_Done20: int = ...
	Message_Done21: int = ...
	Message_Done22: int = ...
	Message_Done23: int = ...
	Message_Done24: int = ...
	Message_Done25: int = ...
	Message_Done26: int = ...
	Message_Done27: int = ...
	Message_Done28: int = ...
	Message_Done29: int = ...
	Message_Done30: int = ...
	Message_Done31: int = ...
	Message_Done32: int = ...
	Message_Warn1: int = ...
	Message_Warn2: int = ...
	Message_Warn3: int = ...
	Message_Warn4: int = ...
	Message_Warn5: int = ...
	Message_Warn6: int = ...
	Message_Warn7: int = ...
	Message_Warn8: int = ...
	Message_Warn9: int = ...
	Message_Warn10: int = ...
	Message_Warn11: int = ...
	Message_Warn12: int = ...
	Message_Warn13: int = ...
	Message_Warn14: int = ...
	Message_Warn15: int = ...
	Message_Warn16: int = ...
	Message_Warn17: int = ...
	Message_Warn18: int = ...
	Message_Warn19: int = ...
	Message_Warn20: int = ...
	Message_Warn21: int = ...
	Message_Warn22: int = ...
	Message_Warn23: int = ...
	Message_Warn24: int = ...
	Message_Warn25: int = ...
	Message_Warn26: int = ...
	Message_Warn27: int = ...
	Message_Warn28: int = ...
	Message_Warn29: int = ...
	Message_Warn30: int = ...
	Message_Warn31: int = ...
	Message_Warn32: int = ...
	Message_Alarm1: int = ...
	Message_Alarm2: int = ...
	Message_Alarm3: int = ...
	Message_Alarm4: int = ...
	Message_Alarm5: int = ...
	Message_Alarm6: int = ...
	Message_Alarm7: int = ...
	Message_Alarm8: int = ...
	Message_Alarm9: int = ...
	Message_Alarm10: int = ...
	Message_Alarm11: int = ...
	Message_Alarm12: int = ...
	Message_Alarm13: int = ...
	Message_Alarm14: int = ...
	Message_Alarm15: int = ...
	Message_Alarm16: int = ...
	Message_Alarm17: int = ...
	Message_Alarm18: int = ...
	Message_Alarm19: int = ...
	Message_Alarm20: int = ...
	Message_Alarm21: int = ...
	Message_Alarm22: int = ...
	Message_Alarm23: int = ...
	Message_Alarm24: int = ...
	Message_Alarm25: int = ...
	Message_Alarm26: int = ...
	Message_Alarm27: int = ...
	Message_Alarm28: int = ...
	Message_Alarm29: int = ...
	Message_Alarm30: int = ...
	Message_Alarm31: int = ...
	Message_Alarm32: int = ...
	Message_Fail1: int = ...
	Message_Fail2: int = ...
	Message_Fail3: int = ...
	Message_Fail4: int = ...
	Message_Fail5: int = ...
	Message_Fail6: int = ...
	Message_Fail7: int = ...
	Message_Fail8: int = ...
	Message_Fail9: int = ...
	Message_Fail10: int = ...
	Message_Fail11: int = ...
	Message_Fail12: int = ...
	Message_Fail13: int = ...
	Message_Fail14: int = ...
	Message_Fail15: int = ...
	Message_Fail16: int = ...
	Message_Fail17: int = ...
	Message_Fail18: int = ...
	Message_Fail19: int = ...
	Message_Fail20: int = ...
	Message_Fail21: int = ...
	Message_Fail22: int = ...
	Message_Fail23: int = ...
	Message_Fail24: int = ...
	Message_Fail25: int = ...
	Message_Fail26: int = ...
	Message_Fail27: int = ...
	Message_Fail28: int = ...
	Message_Fail29: int = ...
	Message_Fail30: int = ...
	Message_Fail31: int = ...
	Message_Fail32: int = ...
Message_None = Message_Status.Message_None
Message_Done1 = Message_Status.Message_Done1
Message_Done2 = Message_Status.Message_Done2
Message_Done3 = Message_Status.Message_Done3
Message_Done4 = Message_Status.Message_Done4
Message_Done5 = Message_Status.Message_Done5
Message_Done6 = Message_Status.Message_Done6
Message_Done7 = Message_Status.Message_Done7
Message_Done8 = Message_Status.Message_Done8
Message_Done9 = Message_Status.Message_Done9
Message_Done10 = Message_Status.Message_Done10
Message_Done11 = Message_Status.Message_Done11
Message_Done12 = Message_Status.Message_Done12
Message_Done13 = Message_Status.Message_Done13
Message_Done14 = Message_Status.Message_Done14
Message_Done15 = Message_Status.Message_Done15
Message_Done16 = Message_Status.Message_Done16
Message_Done17 = Message_Status.Message_Done17
Message_Done18 = Message_Status.Message_Done18
Message_Done19 = Message_Status.Message_Done19
Message_Done20 = Message_Status.Message_Done20
Message_Done21 = Message_Status.Message_Done21
Message_Done22 = Message_Status.Message_Done22
Message_Done23 = Message_Status.Message_Done23
Message_Done24 = Message_Status.Message_Done24
Message_Done25 = Message_Status.Message_Done25
Message_Done26 = Message_Status.Message_Done26
Message_Done27 = Message_Status.Message_Done27
Message_Done28 = Message_Status.Message_Done28
Message_Done29 = Message_Status.Message_Done29
Message_Done30 = Message_Status.Message_Done30
Message_Done31 = Message_Status.Message_Done31
Message_Done32 = Message_Status.Message_Done32
Message_Warn1 = Message_Status.Message_Warn1
Message_Warn2 = Message_Status.Message_Warn2
Message_Warn3 = Message_Status.Message_Warn3
Message_Warn4 = Message_Status.Message_Warn4
Message_Warn5 = Message_Status.Message_Warn5
Message_Warn6 = Message_Status.Message_Warn6
Message_Warn7 = Message_Status.Message_Warn7
Message_Warn8 = Message_Status.Message_Warn8
Message_Warn9 = Message_Status.Message_Warn9
Message_Warn10 = Message_Status.Message_Warn10
Message_Warn11 = Message_Status.Message_Warn11
Message_Warn12 = Message_Status.Message_Warn12
Message_Warn13 = Message_Status.Message_Warn13
Message_Warn14 = Message_Status.Message_Warn14
Message_Warn15 = Message_Status.Message_Warn15
Message_Warn16 = Message_Status.Message_Warn16
Message_Warn17 = Message_Status.Message_Warn17
Message_Warn18 = Message_Status.Message_Warn18
Message_Warn19 = Message_Status.Message_Warn19
Message_Warn20 = Message_Status.Message_Warn20
Message_Warn21 = Message_Status.Message_Warn21
Message_Warn22 = Message_Status.Message_Warn22
Message_Warn23 = Message_Status.Message_Warn23
Message_Warn24 = Message_Status.Message_Warn24
Message_Warn25 = Message_Status.Message_Warn25
Message_Warn26 = Message_Status.Message_Warn26
Message_Warn27 = Message_Status.Message_Warn27
Message_Warn28 = Message_Status.Message_Warn28
Message_Warn29 = Message_Status.Message_Warn29
Message_Warn30 = Message_Status.Message_Warn30
Message_Warn31 = Message_Status.Message_Warn31
Message_Warn32 = Message_Status.Message_Warn32
Message_Alarm1 = Message_Status.Message_Alarm1
Message_Alarm2 = Message_Status.Message_Alarm2
Message_Alarm3 = Message_Status.Message_Alarm3
Message_Alarm4 = Message_Status.Message_Alarm4
Message_Alarm5 = Message_Status.Message_Alarm5
Message_Alarm6 = Message_Status.Message_Alarm6
Message_Alarm7 = Message_Status.Message_Alarm7
Message_Alarm8 = Message_Status.Message_Alarm8
Message_Alarm9 = Message_Status.Message_Alarm9
Message_Alarm10 = Message_Status.Message_Alarm10
Message_Alarm11 = Message_Status.Message_Alarm11
Message_Alarm12 = Message_Status.Message_Alarm12
Message_Alarm13 = Message_Status.Message_Alarm13
Message_Alarm14 = Message_Status.Message_Alarm14
Message_Alarm15 = Message_Status.Message_Alarm15
Message_Alarm16 = Message_Status.Message_Alarm16
Message_Alarm17 = Message_Status.Message_Alarm17
Message_Alarm18 = Message_Status.Message_Alarm18
Message_Alarm19 = Message_Status.Message_Alarm19
Message_Alarm20 = Message_Status.Message_Alarm20
Message_Alarm21 = Message_Status.Message_Alarm21
Message_Alarm22 = Message_Status.Message_Alarm22
Message_Alarm23 = Message_Status.Message_Alarm23
Message_Alarm24 = Message_Status.Message_Alarm24
Message_Alarm25 = Message_Status.Message_Alarm25
Message_Alarm26 = Message_Status.Message_Alarm26
Message_Alarm27 = Message_Status.Message_Alarm27
Message_Alarm28 = Message_Status.Message_Alarm28
Message_Alarm29 = Message_Status.Message_Alarm29
Message_Alarm30 = Message_Status.Message_Alarm30
Message_Alarm31 = Message_Status.Message_Alarm31
Message_Alarm32 = Message_Status.Message_Alarm32
Message_Fail1 = Message_Status.Message_Fail1
Message_Fail2 = Message_Status.Message_Fail2
Message_Fail3 = Message_Status.Message_Fail3
Message_Fail4 = Message_Status.Message_Fail4
Message_Fail5 = Message_Status.Message_Fail5
Message_Fail6 = Message_Status.Message_Fail6
Message_Fail7 = Message_Status.Message_Fail7
Message_Fail8 = Message_Status.Message_Fail8
Message_Fail9 = Message_Status.Message_Fail9
Message_Fail10 = Message_Status.Message_Fail10
Message_Fail11 = Message_Status.Message_Fail11
Message_Fail12 = Message_Status.Message_Fail12
Message_Fail13 = Message_Status.Message_Fail13
Message_Fail14 = Message_Status.Message_Fail14
Message_Fail15 = Message_Status.Message_Fail15
Message_Fail16 = Message_Status.Message_Fail16
Message_Fail17 = Message_Status.Message_Fail17
Message_Fail18 = Message_Status.Message_Fail18
Message_Fail19 = Message_Status.Message_Fail19
Message_Fail20 = Message_Status.Message_Fail20
Message_Fail21 = Message_Status.Message_Fail21
Message_Fail22 = Message_Status.Message_Fail22
Message_Fail23 = Message_Status.Message_Fail23
Message_Fail24 = Message_Status.Message_Fail24
Message_Fail25 = Message_Status.Message_Fail25
Message_Fail26 = Message_Status.Message_Fail26
Message_Fail27 = Message_Status.Message_Fail27
Message_Fail28 = Message_Status.Message_Fail28
Message_Fail29 = Message_Status.Message_Fail29
Message_Fail30 = Message_Status.Message_Fail30
Message_Fail31 = Message_Status.Message_Fail31
Message_Fail32 = Message_Status.Message_Fail32

class Message_ConsoleColor(IntEnum):
	Message_ConsoleColor_Default: int = ...
	Message_ConsoleColor_Black: int = ...
	Message_ConsoleColor_White: int = ...
	Message_ConsoleColor_Red: int = ...
	Message_ConsoleColor_Blue: int = ...
	Message_ConsoleColor_Green: int = ...
	Message_ConsoleColor_Yellow: int = ...
	Message_ConsoleColor_Cyan: int = ...
	Message_ConsoleColor_Magenta: int = ...
Message_ConsoleColor_Default = Message_ConsoleColor.Message_ConsoleColor_Default
Message_ConsoleColor_Black = Message_ConsoleColor.Message_ConsoleColor_Black
Message_ConsoleColor_White = Message_ConsoleColor.Message_ConsoleColor_White
Message_ConsoleColor_Red = Message_ConsoleColor.Message_ConsoleColor_Red
Message_ConsoleColor_Blue = Message_ConsoleColor.Message_ConsoleColor_Blue
Message_ConsoleColor_Green = Message_ConsoleColor.Message_ConsoleColor_Green
Message_ConsoleColor_Yellow = Message_ConsoleColor.Message_ConsoleColor_Yellow
Message_ConsoleColor_Cyan = Message_ConsoleColor.Message_ConsoleColor_Cyan
Message_ConsoleColor_Magenta = Message_ConsoleColor.Message_ConsoleColor_Magenta

class Message_Gravity(IntEnum):
	Message_Trace: int = ...
	Message_Info: int = ...
	Message_Warning: int = ...
	Message_Alarm: int = ...
	Message_Fail: int = ...
Message_Trace = Message_Gravity.Message_Trace
Message_Info = Message_Gravity.Message_Info
Message_Warning = Message_Gravity.Message_Warning
Message_Alarm = Message_Gravity.Message_Alarm
Message_Fail = Message_Gravity.Message_Fail

class Message_MetricType(IntEnum):
	Message_MetricType_None: int = ...
	Message_MetricType_ThreadCPUUserTime: int = ...
	Message_MetricType_ThreadCPUSystemTime: int = ...
	Message_MetricType_ProcessCPUUserTime: int = ...
	Message_MetricType_ProcessCPUSystemTime: int = ...
	Message_MetricType_MemPrivate: int = ...
	Message_MetricType_MemVirtual: int = ...
	Message_MetricType_MemWorkingSet: int = ...
	Message_MetricType_MemWorkingSetPeak: int = ...
	Message_MetricType_MemSwapUsage: int = ...
	Message_MetricType_MemSwapUsagePeak: int = ...
	Message_MetricType_MemHeapUsage: int = ...
Message_MetricType_None = Message_MetricType.Message_MetricType_None
Message_MetricType_ThreadCPUUserTime = Message_MetricType.Message_MetricType_ThreadCPUUserTime
Message_MetricType_ThreadCPUSystemTime = Message_MetricType.Message_MetricType_ThreadCPUSystemTime
Message_MetricType_ProcessCPUUserTime = Message_MetricType.Message_MetricType_ProcessCPUUserTime
Message_MetricType_ProcessCPUSystemTime = Message_MetricType.Message_MetricType_ProcessCPUSystemTime
Message_MetricType_MemPrivate = Message_MetricType.Message_MetricType_MemPrivate
Message_MetricType_MemVirtual = Message_MetricType.Message_MetricType_MemVirtual
Message_MetricType_MemWorkingSet = Message_MetricType.Message_MetricType_MemWorkingSet
Message_MetricType_MemWorkingSetPeak = Message_MetricType.Message_MetricType_MemWorkingSetPeak
Message_MetricType_MemSwapUsage = Message_MetricType.Message_MetricType_MemSwapUsage
Message_MetricType_MemSwapUsagePeak = Message_MetricType.Message_MetricType_MemSwapUsagePeak
Message_MetricType_MemHeapUsage = Message_MetricType.Message_MetricType_MemHeapUsage

class Message_StatusType(IntEnum):
	Message_DONE: int = ...
	Message_WARN: int = ...
	Message_ALARM: int = ...
	Message_FAIL: int = ...
Message_DONE = Message_StatusType.Message_DONE
Message_WARN = Message_StatusType.Message_WARN
Message_ALARM = Message_StatusType.Message_ALARM
Message_FAIL = Message_StatusType.Message_FAIL

class message:
	@staticmethod
	def DefaultMessenger() -> Message_Messenger: ...
	@staticmethod
	def DefaultReport(theToCreate: Optional[bool] = False) -> Message_Report: ...
	@staticmethod
	def FillTime(Hour: int, Minute: int, Second: float) -> TCollection_AsciiString: ...
	@overload
	@staticmethod
	def MetricFromString(theString: str, theType: Message_MetricType) -> bool: ...
	@overload
	@staticmethod
	def MetricFromString(theString: str) -> Message_MetricType: ...
	@staticmethod
	def MetricToString(theType: Message_MetricType) -> str: ...

class Message_Alert(Standard_Transient):
	def GetMessageKey(self) -> str: ...
	def Merge(self, theTarget: Message_Alert) -> bool: ...
	def SupportsMerge(self) -> bool: ...

class Message_Algorithm(Standard_Transient):
	def __init__(self) -> None: ...
	@overload
	def AddStatus(self, theOther: Message_Algorithm) -> None: ...
	@overload
	def AddStatus(self, theStatus: Message_ExecStatus, theOther: Message_Algorithm) -> None: ...
	def ChangeStatus(self) -> Message_ExecStatus: ...
	def ClearStatus(self) -> None: ...
	def GetMessageNumbers(self, theStatus: Message_Status) -> TColStd_HPackedMapOfInteger: ...
	def GetMessageStrings(self, theStatus: Message_Status) -> TColStd_HSequenceOfHExtendedString: ...
	def GetMessenger(self) -> Message_Messenger: ...
	def GetStatus(self) -> Message_ExecStatus: ...
	@overload
	@staticmethod
	def PrepareReport(theError: TColStd_HPackedMapOfInteger, theMaxCount: int) -> TCollection_ExtendedString: ...
	@overload
	@staticmethod
	def PrepareReport(theReportSeq: TColStd_SequenceOfHExtendedString, theMaxCount: int) -> TCollection_ExtendedString: ...
	def SendMessages(self, theTraceLevel: Optional[Message_Gravity] = Message_Warning, theMaxCount: Optional[int] = 20) -> None: ...
	def SendStatusMessages(self, theFilter: Message_ExecStatus, theTraceLevel: Optional[Message_Gravity] = Message_Warning, theMaxCount: Optional[int] = 20) -> None: ...
	def SetMessenger(self, theMsgr: Message_Messenger) -> None: ...
	@overload
	def SetStatus(self, theStat: Message_Status) -> None: ...
	@overload
	def SetStatus(self, theStat: Message_Status, theInt: int) -> None: ...
	@overload
	def SetStatus(self, theStat: Message_Status, theStr: str, noRepetitions: Optional[bool] = True) -> None: ...
	@overload
	def SetStatus(self, theStat: Message_Status, theStr: TCollection_AsciiString, noRepetitions: Optional[bool] = True) -> None: ...
	@overload
	def SetStatus(self, theStat: Message_Status, theStr: TCollection_HAsciiString, noRepetitions: Optional[bool] = True) -> None: ...
	@overload
	def SetStatus(self, theStat: Message_Status, theStr: TCollection_ExtendedString, noRepetitions: Optional[bool] = True) -> None: ...
	@overload
	def SetStatus(self, theStat: Message_Status, theStr: TCollection_HExtendedString, noRepetitions: Optional[bool] = True) -> None: ...
	@overload
	def SetStatus(self, theStat: Message_Status, theMsg: Message_Msg) -> None: ...

class Message_Attribute(Standard_Transient):
	def __init__(self, theName: Optional[TCollection_AsciiString] = TCollection_AsciiString()) -> None: ...
	def GetMessageKey(self) -> str: ...
	def GetName(self) -> TCollection_AsciiString: ...
	def SetName(self, theName: TCollection_AsciiString) -> None: ...

class Message_CompositeAlerts(Standard_Transient):
	def __init__(self) -> None: ...
	def AddAlert(self, theGravity: Message_Gravity, theAlert: Message_Alert) -> bool: ...
	def Alerts(self, theGravity: Message_Gravity) -> Message_ListOfAlert: ...
	@overload
	def Clear(self) -> None: ...
	@overload
	def Clear(self, theGravity: Message_Gravity) -> None: ...
	@overload
	def Clear(self, theType: Standard_Type) -> None: ...
	@overload
	def HasAlert(self, theAlert: Message_Alert) -> bool: ...
	@overload
	def HasAlert(self, theType: Standard_Type, theGravity: Message_Gravity) -> bool: ...
	def RemoveAlert(self, theGravity: Message_Gravity, theAlert: Message_Alert) -> bool: ...

class Message_ExecStatus:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, status: Message_Status) -> None: ...
	def Add(self, theOther: Message_ExecStatus) -> None: ...
	def And(self, theOther: Message_ExecStatus) -> None: ...
	@overload
	def Clear(self, status: Message_Status) -> None: ...
	@overload
	def Clear(self) -> None: ...
	def ClearAllAlarm(self) -> None: ...
	def ClearAllDone(self) -> None: ...
	def ClearAllFail(self) -> None: ...
	def ClearAllWarn(self) -> None: ...
	def IsAlarm(self) -> bool: ...
	def IsDone(self) -> bool: ...
	def IsFail(self) -> bool: ...
	def IsSet(self, status: Message_Status) -> bool: ...
	def IsWarn(self) -> bool: ...
	@staticmethod
	def LocalStatusIndex(status: Message_Status) -> int: ...
	def Set(self, status: Message_Status) -> None: ...
	def SetAllAlarm(self) -> None: ...
	def SetAllDone(self) -> None: ...
	def SetAllFail(self) -> None: ...
	def SetAllWarn(self) -> None: ...
	@staticmethod
	def StatusByIndex(theIndex: int) -> Message_Status: ...
	@staticmethod
	def StatusIndex(status: Message_Status) -> int: ...
	@staticmethod
	def TypeOfStatus(status: Message_Status) -> Message_StatusType: ...

class Message_Level:
	def __init__(self, theName: Optional[TCollection_AsciiString] = TCollection_AsciiString()) -> None: ...
	def AddAlert(self, theGravity: Message_Gravity, theAlert: Message_Alert) -> bool: ...
	def RootAlert(self) -> Message_AlertExtended: ...
	def SetRootAlert(self, theAlert: Message_AlertExtended, isRequiredToStart: bool) -> None: ...

class Message_Messenger(Standard_Transient):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, thePrinter: Message_Printer) -> None: ...
	def AddPrinter(self, thePrinter: Message_Printer) -> bool: ...
	def ChangePrinters(self) -> Message_SequenceOfPrinters: ...
	def Printers(self) -> Message_SequenceOfPrinters: ...
	def RemovePrinter(self, thePrinter: Message_Printer) -> bool: ...
	def RemovePrinters(self, theType: Standard_Type) -> int: ...

class Message_Msg:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theMsg: Message_Msg) -> None: ...
	@overload
	def __init__(self, theKey: str) -> None: ...
	@overload
	def __init__(self, theKey: TCollection_ExtendedString) -> None: ...
	@overload
	def Arg(self, theString: str) -> Message_Msg: ...
	@overload
	def Arg(self, theString: TCollection_AsciiString) -> Message_Msg: ...
	@overload
	def Arg(self, theString: TCollection_HAsciiString) -> Message_Msg: ...
	@overload
	def Arg(self, theString: TCollection_ExtendedString) -> Message_Msg: ...
	@overload
	def Arg(self, theString: TCollection_HExtendedString) -> Message_Msg: ...
	@overload
	def Arg(self, theInt: int) -> Message_Msg: ...
	@overload
	def Arg(self, theReal: float) -> Message_Msg: ...
	def Get(self) -> TCollection_ExtendedString: ...
	def IsEdited(self) -> bool: ...
	def Original(self) -> TCollection_ExtendedString: ...
	@overload
	def Set(self, theMsg: str) -> None: ...
	@overload
	def Set(self, theMsg: TCollection_ExtendedString) -> None: ...
	def Value(self) -> TCollection_ExtendedString: ...

class Message_MsgFile:
	@staticmethod
	def AddMsg(key: TCollection_AsciiString, text: TCollection_ExtendedString) -> bool: ...
	@staticmethod
	def HasMsg(key: TCollection_AsciiString) -> bool: ...
	@staticmethod
	def Load(theDirName: str, theFileName: str) -> bool: ...
	@staticmethod
	def LoadFile(theFName: str) -> bool: ...
	@staticmethod
	def LoadFromEnv(theEnvName: str, theFileName: str, theLangExt: Optional[str] = "") -> bool: ...
	@staticmethod
	def LoadFromString(theContent: str, theLength: Optional[int] = -1) -> bool: ...
	@overload
	@staticmethod
	def Msg(key: str) -> TCollection_ExtendedString: ...
	@overload
	@staticmethod
	def Msg(key: TCollection_AsciiString) -> TCollection_ExtendedString: ...

class Message_Printer(Standard_Transient):
	def GetTraceLevel(self) -> Message_Gravity: ...
	@overload
	def Send(self, theString: TCollection_ExtendedString, theGravity: Message_Gravity) -> None: ...
	@overload
	def Send(self, theString: str, theGravity: Message_Gravity) -> None: ...
	@overload
	def Send(self, theString: TCollection_AsciiString, theGravity: Message_Gravity) -> None: ...
	def SendObject(self, theObject: Standard_Transient, theGravity: Message_Gravity) -> None: ...
	def SendStringStream(self, theStream: Standard_SStream, theGravity: Message_Gravity) -> None: ...
	def SetTraceLevel(self, theTraceLevel: Message_Gravity) -> None: ...

class Message_ProgressIndicator(Standard_Transient):
	def GetPosition(self) -> float: ...
	@overload
	def Start(self) -> Message_ProgressRange: ...
	@overload
	@staticmethod
	def Start(theProgress: Message_ProgressIndicator) -> Message_ProgressRange: ...

class Message_ProgressRange:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theOther: Message_ProgressRange) -> None: ...
	def Close(self) -> None: ...
	def IsActive(self) -> bool: ...
	def More(self) -> bool: ...
	def UserBreak(self) -> bool: ...

class Message_Report(Standard_Transient):
	def __init__(self) -> None: ...
	def ActivateInMessenger(self, toActivate: bool, theMessenger: Optional[Message_Messenger] = None) -> None: ...
	def ActiveMetrics(self) -> False: ...
	def AddAlert(self, theGravity: Message_Gravity, theAlert: Message_Alert) -> None: ...
	def AddLevel(self, theLevel: Message_Level, theName: TCollection_AsciiString) -> None: ...
	@overload
	def Clear(self) -> None: ...
	@overload
	def Clear(self, theGravity: Message_Gravity) -> None: ...
	@overload
	def Clear(self, theType: Standard_Type) -> None: ...
	def ClearMetrics(self) -> None: ...
	def GetAlerts(self, theGravity: Message_Gravity) -> Message_ListOfAlert: ...
	@overload
	def HasAlert(self, theType: Standard_Type) -> bool: ...
	@overload
	def HasAlert(self, theType: Standard_Type, theGravity: Message_Gravity) -> bool: ...
	def IsActiveInMessenger(self, theMessenger: Optional[Message_Messenger] = None) -> bool: ...
	def Limit(self) -> int: ...
	@overload
	def Merge(self, theOther: Message_Report) -> None: ...
	@overload
	def Merge(self, theOther: Message_Report, theGravity: Message_Gravity) -> None: ...
	def RemoveLevel(self, theLevel: Message_Level) -> None: ...
	@overload
	def SendMessages(self, theMessenger: Message_Messenger) -> None: ...
	@overload
	def SendMessages(self, theMessenger: Message_Messenger, theGravity: Message_Gravity) -> None: ...
	def SetActiveMetric(self, theMetricType: Message_MetricType, theActivate: bool) -> None: ...
	def SetLimit(self, theLimit: int) -> None: ...
	def UpdateActiveInMessenger(self, theMessenger: Optional[Message_Messenger] = None) -> None: ...

class Message_AlertExtended(Message_Alert):
	def __init__(self) -> None: ...
	@staticmethod
	def AddAlert(theReport: Message_Report, theAttribute: Message_Attribute, theGravity: Message_Gravity) -> Message_Alert: ...
	def Attribute(self) -> Message_Attribute: ...
	def CompositeAlerts(self, theToCreate: Optional[bool] = False) -> Message_CompositeAlerts: ...
	def GetMessageKey(self) -> str: ...
	def Merge(self, theTarget: Message_Alert) -> bool: ...
	def SetAttribute(self, theAttribute: Message_Attribute) -> None: ...
	def SupportsMerge(self) -> bool: ...

class Message_AttributeMeter(Message_Attribute):
	def __init__(self, theName: Optional[TCollection_AsciiString] = TCollection_AsciiString()) -> None: ...
	def HasMetric(self, theMetric: Message_MetricType) -> bool: ...
	def IsMetricValid(self, theMetric: Message_MetricType) -> bool: ...
	@staticmethod
	def SetAlertMetrics(theAlert: Message_AlertExtended, theStartValue: bool) -> None: ...
	def SetStartValue(self, theMetric: Message_MetricType, theValue: float) -> None: ...
	def SetStopValue(self, theMetric: Message_MetricType, theValue: float) -> None: ...
	@staticmethod
	def StartAlert(theAlert: Message_AlertExtended) -> None: ...
	def StartValue(self, theMetric: Message_MetricType) -> float: ...
	@staticmethod
	def StopAlert(theAlert: Message_AlertExtended) -> None: ...
	def StopValue(self, theMetric: Message_MetricType) -> float: ...
	@staticmethod
	def UndefinedMetricValue() -> float: ...

class Message_AttributeObject(Message_Attribute):
	def __init__(self, theObject: Standard_Transient, theName: Optional[TCollection_AsciiString] = TCollection_AsciiString()) -> None: ...
	def Object(self) -> Standard_Transient: ...
	def SetObject(self, theObject: Standard_Transient) -> None: ...

class Message_AttributeStream(Message_Attribute):
	def __init__(self, theStream: Standard_SStream, theName: Optional[TCollection_AsciiString] = TCollection_AsciiString()) -> None: ...
	def SetStream(self, theStream: Standard_SStream) -> None: ...
	def Stream(self) -> Standard_SStream: ...

class Message_PrinterOStream(Message_Printer):
	@overload
	def __init__(self, theTraceLevel: Optional[Message_Gravity] = Message_Info) -> None: ...
	@overload
	def __init__(self, theFileName: str, theDoAppend: bool, theTraceLevel: Optional[Message_Gravity] = Message_Info) -> None: ...
	def Close(self) -> None: ...
	def GetStream(self) -> Standard_OStream: ...
	def SetToColorize(self, theToColorize: bool) -> None: ...
	def ToColorize(self) -> bool: ...

class Message_PrinterSystemLog(Message_Printer):
	def __init__(self, theEventSourceName: TCollection_AsciiString, theTraceLevel: Optional[Message_Gravity] = Message_Info) -> None: ...

class Message_PrinterToReport(Message_Printer):
	def __init__(self) -> None: ...
	def Report(self) -> Message_Report: ...
	def SendObject(self, theObject: Standard_Transient, theGravity: Message_Gravity) -> None: ...
	def SendStringStream(self, theStream: Standard_SStream, theGravity: Message_Gravity) -> None: ...
	def SetReport(self, theReport: Message_Report) -> None: ...

class Message_ProgressSentry(Message_ProgressScope):
	def __init__(self, theRange: Message_ProgressRange, theName: str, theMin: float, theMax: float, theStep: float, theIsInf: Optional[bool] = False, theNewScopeSpan: Optional[float] = 0.0) -> None: ...
	def Relieve(self) -> None: ...

#classnotwrapped
class Message_ProgressScope: ...

# harray1 classes
# harray2 classes
# hsequence classes

message_DefaultMessenger = message.DefaultMessenger
message_DefaultReport = message.DefaultReport
message_FillTime = message.FillTime
message_MetricFromString = message.MetricFromString
message_MetricFromString = message.MetricFromString
message_MetricToString = message.MetricToString
message_ToMessageMetric = message.ToMessageMetric
message_ToOSDMetric = message.ToOSDMetric
Message_Algorithm_PrepareReport = Message_Algorithm.PrepareReport
Message_Algorithm_PrepareReport = Message_Algorithm.PrepareReport
Message_ExecStatus_LocalStatusIndex = Message_ExecStatus.LocalStatusIndex
Message_ExecStatus_StatusByIndex = Message_ExecStatus.StatusByIndex
Message_ExecStatus_StatusIndex = Message_ExecStatus.StatusIndex
Message_ExecStatus_TypeOfStatus = Message_ExecStatus.TypeOfStatus
Message_MsgFile_AddMsg = Message_MsgFile.AddMsg
Message_MsgFile_HasMsg = Message_MsgFile.HasMsg
Message_MsgFile_Load = Message_MsgFile.Load
Message_MsgFile_LoadFile = Message_MsgFile.LoadFile
Message_MsgFile_LoadFromEnv = Message_MsgFile.LoadFromEnv
Message_MsgFile_LoadFromString = Message_MsgFile.LoadFromString
Message_MsgFile_Msg = Message_MsgFile.Msg
Message_MsgFile_Msg = Message_MsgFile.Msg
Message_ProgressIndicator_Start = Message_ProgressIndicator.Start
Message_AlertExtended_AddAlert = Message_AlertExtended.AddAlert
Message_AttributeMeter_SetAlertMetrics = Message_AttributeMeter.SetAlertMetrics
Message_AttributeMeter_StartAlert = Message_AttributeMeter.StartAlert
Message_AttributeMeter_StopAlert = Message_AttributeMeter.StopAlert
Message_AttributeMeter_UndefinedMetricValue = Message_AttributeMeter.UndefinedMetricValue
Message_PrinterOStream_SetConsoleTextColor = Message_PrinterOStream.SetConsoleTextColor



# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
Media module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_media.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _Media
else:
    import _Media

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _Media.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _Media.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _Media.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _Media.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _Media.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _Media.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _Media.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _Media.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _Media.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _Media.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _Media.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _Media.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _Media.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _Media.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _Media.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _Media.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _Media.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _Media:
_Media.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _Media.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.TCollection
import OCC.Core.Image
import OCC.Core.Graphic3d
import OCC.Core.BVH
import OCC.Core.Quantity
import OCC.Core.gp
import OCC.Core.TColStd
import OCC.Core.Aspect
import OCC.Core.TopLoc
import OCC.Core.Bnd
import OCC.Core.TColgp
import OCC.Core.OSD

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_Media_BufferPool_Create() -> "opencascade::handle< Media_BufferPool >":
    return _Media.Handle_Media_BufferPool_Create()

def Handle_Media_BufferPool_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< Media_BufferPool >":
    return _Media.Handle_Media_BufferPool_DownCast(t)

def Handle_Media_BufferPool_IsNull(t: "opencascade::handle< Media_BufferPool > const &") -> "bool":
    return _Media.Handle_Media_BufferPool_IsNull(t)

def Handle_Media_CodecContext_Create() -> "opencascade::handle< Media_CodecContext >":
    return _Media.Handle_Media_CodecContext_Create()

def Handle_Media_CodecContext_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< Media_CodecContext >":
    return _Media.Handle_Media_CodecContext_DownCast(t)

def Handle_Media_CodecContext_IsNull(t: "opencascade::handle< Media_CodecContext > const &") -> "bool":
    return _Media.Handle_Media_CodecContext_IsNull(t)

def Handle_Media_FormatContext_Create() -> "opencascade::handle< Media_FormatContext >":
    return _Media.Handle_Media_FormatContext_Create()

def Handle_Media_FormatContext_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< Media_FormatContext >":
    return _Media.Handle_Media_FormatContext_DownCast(t)

def Handle_Media_FormatContext_IsNull(t: "opencascade::handle< Media_FormatContext > const &") -> "bool":
    return _Media.Handle_Media_FormatContext_IsNull(t)

def Handle_Media_Frame_Create() -> "opencascade::handle< Media_Frame >":
    return _Media.Handle_Media_Frame_Create()

def Handle_Media_Frame_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< Media_Frame >":
    return _Media.Handle_Media_Frame_DownCast(t)

def Handle_Media_Frame_IsNull(t: "opencascade::handle< Media_Frame > const &") -> "bool":
    return _Media.Handle_Media_Frame_IsNull(t)

def Handle_Media_Packet_Create() -> "opencascade::handle< Media_Packet >":
    return _Media.Handle_Media_Packet_Create()

def Handle_Media_Packet_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< Media_Packet >":
    return _Media.Handle_Media_Packet_DownCast(t)

def Handle_Media_Packet_IsNull(t: "opencascade::handle< Media_Packet > const &") -> "bool":
    return _Media.Handle_Media_Packet_IsNull(t)

def Handle_Media_PlayerContext_Create() -> "opencascade::handle< Media_PlayerContext >":
    return _Media.Handle_Media_PlayerContext_Create()

def Handle_Media_PlayerContext_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< Media_PlayerContext >":
    return _Media.Handle_Media_PlayerContext_DownCast(t)

def Handle_Media_PlayerContext_IsNull(t: "opencascade::handle< Media_PlayerContext > const &") -> "bool":
    return _Media.Handle_Media_PlayerContext_IsNull(t)

def Handle_Media_Scaler_Create() -> "opencascade::handle< Media_Scaler >":
    return _Media.Handle_Media_Scaler_Create()

def Handle_Media_Scaler_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< Media_Scaler >":
    return _Media.Handle_Media_Scaler_DownCast(t)

def Handle_Media_Scaler_IsNull(t: "opencascade::handle< Media_Scaler > const &") -> "bool":
    return _Media.Handle_Media_Scaler_IsNull(t)

def Handle_Media_Timer_Create() -> "opencascade::handle< Media_Timer >":
    return _Media.Handle_Media_Timer_Create()

def Handle_Media_Timer_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< Media_Timer >":
    return _Media.Handle_Media_Timer_DownCast(t)

def Handle_Media_Timer_IsNull(t: "opencascade::handle< Media_Timer > const &") -> "bool":
    return _Media.Handle_Media_Timer_IsNull(t)
class Media_BufferPool(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _Media.Media_BufferPool_swiginit(self, _Media.new_Media_BufferPool(*args))

    def BufferSize(self, *args) -> "int":
        r"""
        Return buffer size within the pool.

        Returns
        -------
        int

        """
        return _Media.Media_BufferPool_BufferSize(self, *args)

    def GetBuffer(self, *args) -> "AVBufferRef *":
        r"""
        Get new buffer from the pool.

        Returns
        -------
        AVBufferRef *

        """
        return _Media.Media_BufferPool_GetBuffer(self, *args)

    def Init(self, *args) -> "bool":
        r"""
        (re-)initialize the pool.

        Parameters
        ----------
        theBufferSize: int

        Returns
        -------
        bool

        """
        return _Media.Media_BufferPool_Init(self, *args)

    def Release(self, *args) -> "void":
        r"""
        Release the pool (reference-counted buffer will be released when needed).

        Returns
        -------
        None

        """
        return _Media.Media_BufferPool_Release(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_Media_BufferPool_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _Media.delete_Media_BufferPool

# Register Media_BufferPool in _Media:
_Media.Media_BufferPool_swigregister(Media_BufferPool)

class Media_CodecContext(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Constructor.

        Returns
        -------
        None

        """
        _Media.Media_CodecContext_swiginit(self, _Media.new_Media_CodecContext(*args))

    def CanProcessPacket(self, *args) -> "bool":
        r"""
        Return true if packet belongs to this stream.

        Parameters
        ----------
        thePacket: Media_Packet

        Returns
        -------
        bool

        """
        return _Media.Media_CodecContext_CanProcessPacket(self, *args)

    def Close(self, *args) -> "void":
        r"""
        Close input.

        Returns
        -------
        None

        """
        return _Media.Media_CodecContext_Close(self, *args)

    def Context(self, *args) -> "AVCodecContext *":
        r"""
        Return context.

        Returns
        -------
        AVCodecContext *

        """
        return _Media.Media_CodecContext_Context(self, *args)

    def Flush(self, *args) -> "void":
        r"""
        Avcodec_flush_buffers() wrapper.

        Returns
        -------
        None

        """
        return _Media.Media_CodecContext_Flush(self, *args)

    def Init(self, *args) -> "bool":
        r"""
        Open codec specified within the stream. @param thestream stream to open @param theptsstartbase pts start in seconds @param thenbthreads amount of threads to use for avmedia_type_video stream; -1 means osd_parallel::nblogicalprocessors(),  0 means auto by ffmpeg itself >0 means specified number of threads (decoder should support multi-threading to take effect).

        Parameters
        ----------
        theStream: AVStream
        thePtsStartBase: double
        theNbThreads: int,optional
        	default value is -1

        Returns
        -------
        bool
        Open codec. @param thestream stream to open @param theptsstartbase pts start in seconds @param thenbthreads amount of threads to use for avmedia_type_video stream; -1 means osd_parallel::nblogicalprocessors(),  0 means auto by ffmpeg itself >0 means specified number of threads (decoder should support multi-threading to take effect) @param thecodecid codec (avcodecid) to open.

        Parameters
        ----------
        theStream: AVStream
        thePtsStartBase: double
        theNbThreads: int
        theCodecId: int

        Returns
        -------
        bool

        """
        return _Media.Media_CodecContext_Init(self, *args)

    def ReceiveFrame(self, *args) -> "bool":
        r"""
        Avcodec_receive_frame() wrapper.

        Parameters
        ----------
        theFrame: Media_Frame

        Returns
        -------
        bool

        """
        return _Media.Media_CodecContext_ReceiveFrame(self, *args)

    def SendPacket(self, *args) -> "bool":
        r"""
        Avcodec_send_packet() wrapper.

        Parameters
        ----------
        thePacket: Media_Packet

        Returns
        -------
        bool

        """
        return _Media.Media_CodecContext_SendPacket(self, *args)

    def SizeX(self, *args) -> "int":
        r"""
        Returns source frame width.

        Returns
        -------
        int

        """
        return _Media.Media_CodecContext_SizeX(self, *args)

    def SizeY(self, *args) -> "int":
        r"""
        Returns source frame height.

        Returns
        -------
        int

        """
        return _Media.Media_CodecContext_SizeY(self, *args)

    def StreamIndex(self, *args) -> "int":
        r"""
        Return stream index.

        Returns
        -------
        int

        """
        return _Media.Media_CodecContext_StreamIndex(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_Media_CodecContext_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _Media.delete_Media_CodecContext

# Register Media_CodecContext in _Media:
_Media.Media_CodecContext_swigregister(Media_CodecContext)

class Media_FormatContext(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Constructor.

        Returns
        -------
        None

        """
        _Media.Media_FormatContext_swiginit(self, _Media.new_Media_FormatContext(*args))

    def Close(self, *args) -> "void":
        r"""
        Close input.

        Returns
        -------
        None

        """
        return _Media.Media_FormatContext_Close(self, *args)

    def Context(self, *args) -> "AVFormatContext *":
        r"""
        Return context.

        Returns
        -------
        AVFormatContext *

        """
        return _Media.Media_FormatContext_Context(self, *args)

    def Duration(self, *args) -> "double":
        r"""
        Return duration in seconds.

        Returns
        -------
        double

        """
        return _Media.Media_FormatContext_Duration(self, *args)

    @staticmethod
    def FormatAVErrorDescription(*args) -> "TCollection_AsciiString":
        r"""
        Returns string description for averror code.

        Parameters
        ----------
        theErrCodeAV: int

        Returns
        -------
        TCollection_AsciiString

        """
        return _Media.Media_FormatContext_FormatAVErrorDescription(*args)

    @staticmethod
    def FormatTime(*args) -> "TCollection_AsciiString":
        r"""
        Time formatter.

        Parameters
        ----------
        theSeconds: double

        Returns
        -------
        TCollection_AsciiString

        """
        return _Media.Media_FormatContext_FormatTime(*args)

    @staticmethod
    def FormatTimeProgress(*args) -> "TCollection_AsciiString":
        r"""
        Time progress / duration formatter.

        Parameters
        ----------
        theProgress: double
        theDuration: double

        Returns
        -------
        TCollection_AsciiString

        """
        return _Media.Media_FormatContext_FormatTimeProgress(*args)

    @staticmethod
    def FormatUnitsToSeconds(*args) -> "double":
        r"""
        Convert time units into seconds for context. @param thetimeunits value to convert returns converted time units in seconds.

        Parameters
        ----------
        theTimeUnits: int64_t

        Returns
        -------
        double

        """
        return _Media.Media_FormatContext_FormatUnitsToSeconds(*args)

    def NbSteams(self, *args) -> "unsigned int":
        r"""
        Return amount of streams.

        Returns
        -------
        unsigned int

        """
        return _Media.Media_FormatContext_NbSteams(self, *args)

    def OpenInput(self, *args) -> "bool":
        r"""
        Open input.

        Parameters
        ----------
        theInput: TCollection_AsciiString

        Returns
        -------
        bool

        """
        return _Media.Media_FormatContext_OpenInput(self, *args)

    def PtsStartBase(self, *args) -> "double":
        r"""
        Return pts start base in seconds.

        Returns
        -------
        double

        """
        return _Media.Media_FormatContext_PtsStartBase(self, *args)

    def ReadPacket(self, *args) -> "bool":
        r"""
        Av_read_frame() wrapper.

        Parameters
        ----------
        thePacket: Media_Packet

        Returns
        -------
        bool

        """
        return _Media.Media_FormatContext_ReadPacket(self, *args)

    @staticmethod
    def SecondsToUnits(*args) -> "int64_t":
        r"""
        Convert seconds into time units for context. @param thetimeseconds value to convert returns time units.

        Parameters
        ----------
        theTimeSeconds: double

        Returns
        -------
        int64_t
        Convert seconds into time units. @param thetimebase the timebase @param thetimeseconds value to convert returns time units.

        Parameters
        ----------
        theTimeBase: AVRational
        theTimeSeconds: double

        Returns
        -------
        int64_t

        """
        return _Media.Media_FormatContext_SecondsToUnits(*args)

    def Seek(self, *args) -> "bool":
        r"""
        Seek context to specified position.

        Parameters
        ----------
        theSeekPts: double
        toSeekBack: bool

        Returns
        -------
        bool

        """
        return _Media.Media_FormatContext_Seek(self, *args)

    def SeekStream(self, *args) -> "bool":
        r"""
        Seek stream to specified position.

        Parameters
        ----------
        theStreamId: unsigned int
        theSeekPts: double
        toSeekBack: bool

        Returns
        -------
        bool

        """
        return _Media.Media_FormatContext_SeekStream(self, *args)

    def Stream(self, *args) -> "AVStream const &":
        r"""
        Return stream.

        Parameters
        ----------
        theIndex: unsigned int

        Returns
        -------
        AVStream

        """
        return _Media.Media_FormatContext_Stream(self, *args)

    def StreamInfo(self, *args) -> "TCollection_AsciiString":
        r"""
        Format stream info.

        Parameters
        ----------
        theIndex: unsigned int
        theCodecCtx: AVCodecContext *,optional
        	default value is NULL

        Returns
        -------
        TCollection_AsciiString

        """
        return _Media.Media_FormatContext_StreamInfo(self, *args)

    @staticmethod
    def StreamSecondsToUnits(*args) -> "int64_t":
        r"""
        Convert seconds into time units for stream. @param thestream the stream @param thetimeseconds value to convert returns time units.

        Parameters
        ----------
        theStream: AVStream
        theTimeSeconds: double

        Returns
        -------
        int64_t

        """
        return _Media.Media_FormatContext_StreamSecondsToUnits(*args)

    @staticmethod
    def StreamUnitsToSeconds(*args) -> "double":
        r"""
        Convert time units into seconds using stream base. @param thestream the stream; @param thetimeunits value to convert; returns converted time units in seconds.

        Parameters
        ----------
        theStream: AVStream
        theTimeUnits: int64_t

        Returns
        -------
        double

        """
        return _Media.Media_FormatContext_StreamUnitsToSeconds(*args)

    @staticmethod
    def UnitsToSeconds(*args) -> "double":
        r"""
        Convert time units into seconds. returns zero for invalid value. @param thetimebase the timebase @param thetimeunits value to convert returns converted time units in seconds.

        Parameters
        ----------
        theTimeBase: AVRational
        theTimeUnits: int64_t

        Returns
        -------
        double

        """
        return _Media.Media_FormatContext_UnitsToSeconds(*args)


    @staticmethod
    def DownCast(t):
      return Handle_Media_FormatContext_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _Media.delete_Media_FormatContext

# Register Media_FormatContext in _Media:
_Media.Media_FormatContext_swigregister(Media_FormatContext)

def Media_FormatContext_FormatAVErrorDescription(*args) -> "TCollection_AsciiString":
    r"""
    Returns string description for averror code.

    Parameters
    ----------
    theErrCodeAV: int

    Returns
    -------
    TCollection_AsciiString

    """
    return _Media.Media_FormatContext_FormatAVErrorDescription(*args)

def Media_FormatContext_FormatTime(*args) -> "TCollection_AsciiString":
    r"""
    Time formatter.

    Parameters
    ----------
    theSeconds: double

    Returns
    -------
    TCollection_AsciiString

    """
    return _Media.Media_FormatContext_FormatTime(*args)

def Media_FormatContext_FormatTimeProgress(*args) -> "TCollection_AsciiString":
    r"""
    Time progress / duration formatter.

    Parameters
    ----------
    theProgress: double
    theDuration: double

    Returns
    -------
    TCollection_AsciiString

    """
    return _Media.Media_FormatContext_FormatTimeProgress(*args)

def Media_FormatContext_FormatUnitsToSeconds(*args) -> "double":
    r"""
    Convert time units into seconds for context. @param thetimeunits value to convert returns converted time units in seconds.

    Parameters
    ----------
    theTimeUnits: int64_t

    Returns
    -------
    double

    """
    return _Media.Media_FormatContext_FormatUnitsToSeconds(*args)

def Media_FormatContext_SecondsToUnits(*args) -> "int64_t":
    r"""
    Convert seconds into time units for context. @param thetimeseconds value to convert returns time units.

    Parameters
    ----------
    theTimeSeconds: double

    Returns
    -------
    int64_t
    Convert seconds into time units. @param thetimebase the timebase @param thetimeseconds value to convert returns time units.

    Parameters
    ----------
    theTimeBase: AVRational
    theTimeSeconds: double

    Returns
    -------
    int64_t

    """
    return _Media.Media_FormatContext_SecondsToUnits(*args)

def Media_FormatContext_StreamSecondsToUnits(*args) -> "int64_t":
    r"""
    Convert seconds into time units for stream. @param thestream the stream @param thetimeseconds value to convert returns time units.

    Parameters
    ----------
    theStream: AVStream
    theTimeSeconds: double

    Returns
    -------
    int64_t

    """
    return _Media.Media_FormatContext_StreamSecondsToUnits(*args)

def Media_FormatContext_StreamUnitsToSeconds(*args) -> "double":
    r"""
    Convert time units into seconds using stream base. @param thestream the stream; @param thetimeunits value to convert; returns converted time units in seconds.

    Parameters
    ----------
    theStream: AVStream
    theTimeUnits: int64_t

    Returns
    -------
    double

    """
    return _Media.Media_FormatContext_StreamUnitsToSeconds(*args)

def Media_FormatContext_UnitsToSeconds(*args) -> "double":
    r"""
    Convert time units into seconds. returns zero for invalid value. @param thetimebase the timebase @param thetimeunits value to convert returns converted time units in seconds.

    Parameters
    ----------
    theTimeBase: AVRational
    theTimeUnits: int64_t

    Returns
    -------
    double

    """
    return _Media.Media_FormatContext_UnitsToSeconds(*args)

class Media_Frame(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _Media.Media_Frame_swiginit(self, _Media.new_Media_Frame(*args))

    def BestEffortTimestamp(self, *args) -> "int64_t":
        r"""
        Returns frame timestamp estimated using various heuristics, in stream time base.

        Returns
        -------
        int64_t

        """
        return _Media.Media_Frame_BestEffortTimestamp(self, *args)

    def ChangeFrame(self, *args) -> "AVFrame *":
        r"""
        Return frame.

        Returns
        -------
        AVFrame *

        """
        return _Media.Media_Frame_ChangeFrame(self, *args)

    def Format(self, *args) -> "int":
        r"""
        Return pixel format (avpixelformat).

        Returns
        -------
        int

        """
        return _Media.Media_Frame_Format(self, *args)

    @staticmethod
    def FormatFFmpeg2Occt(*args) -> "Image_Format":
        r"""
        Convert pixel format from ffmpeg (avpixelformat) to occt.

        Parameters
        ----------
        theFormat: int

        Returns
        -------
        Image_Format

        """
        return _Media.Media_Frame_FormatFFmpeg2Occt(*args)

    @staticmethod
    def FormatOcct2FFmpeg(*args) -> "int":
        r"""
        Convert pixel format from occt to ffmpeg (avpixelformat). returns -1 (av_pix_fmt_none) if undefined.

        Parameters
        ----------
        theFormat: Image_Format

        Returns
        -------
        int

        """
        return _Media.Media_Frame_FormatOcct2FFmpeg(*args)

    def Frame(self, *args) -> "AVFrame const *":
        r"""
        Return frame.

        Returns
        -------
        AVFrame *

        """
        return _Media.Media_Frame_Frame(self, *args)

    def InitWrapper(self, *args) -> "bool":
        r"""
        Wrap allocated image pixmap.

        Parameters
        ----------
        thePixMap: Image_PixMap

        Returns
        -------
        bool

        """
        return _Media.Media_Frame_InitWrapper(self, *args)

    def IsEmpty(self, *args) -> "bool":
        r"""
        Return true if frame does not contain any data.

        Returns
        -------
        bool

        """
        return _Media.Media_Frame_IsEmpty(self, *args)

    def IsFullRangeYUV(self, *args) -> "bool":
        r"""
        Return true if yuv range is full.

        Returns
        -------
        bool

        """
        return _Media.Media_Frame_IsFullRangeYUV(self, *args)

    def IsLocked(self, *args) -> "bool":
        r"""
        Return locked state.

        Returns
        -------
        bool

        """
        return _Media.Media_Frame_IsLocked(self, *args)

    def LineSize(self, *args) -> "int":
        r"""
        Returns linesize in bytes for specified data plane.

        Parameters
        ----------
        thePlaneId: int

        Returns
        -------
        int

        """
        return _Media.Media_Frame_LineSize(self, *args)

    def PixelAspectRatio(self, *args) -> "float":
        r"""
        Return par.

        Returns
        -------
        float

        """
        return _Media.Media_Frame_PixelAspectRatio(self, *args)

    def Plane(self, *args) -> "uint8_t *":
        r"""
        Access data plane for specified id.

        Parameters
        ----------
        thePlaneId: int

        Returns
        -------
        uint8_t *

        """
        return _Media.Media_Frame_Plane(self, *args)

    def Pts(self, *args) -> "double":
        r"""
        Return presentation timestamp (pts).

        Returns
        -------
        double

        """
        return _Media.Media_Frame_Pts(self, *args)

    def SetLocked(self, *args) -> "void":
        r"""
        Lock/free frame for edition.

        Parameters
        ----------
        theToLock: bool

        Returns
        -------
        None

        """
        return _Media.Media_Frame_SetLocked(self, *args)

    def SetPixelAspectRatio(self, *args) -> "void":
        r"""
        Set par.

        Parameters
        ----------
        theRatio: float

        Returns
        -------
        None

        """
        return _Media.Media_Frame_SetPixelAspectRatio(self, *args)

    def SetPts(self, *args) -> "void":
        r"""
        Set presentation timestamp (pts).

        Parameters
        ----------
        thePts: double

        Returns
        -------
        None

        """
        return _Media.Media_Frame_SetPts(self, *args)

    def Size(self, *args) -> "Graphic3d_Vec2i":
        r"""
        Return image dimensions.

        Returns
        -------
        Graphic3d_Vec2i

        """
        return _Media.Media_Frame_Size(self, *args)

    def SizeX(self, *args) -> "int":
        r"""
        Return image width.

        Returns
        -------
        int

        """
        return _Media.Media_Frame_SizeX(self, *args)

    def SizeY(self, *args) -> "int":
        r"""
        Return image height.

        Returns
        -------
        int

        """
        return _Media.Media_Frame_SizeY(self, *args)

    @staticmethod
    def Swap(*args) -> "void":
        r"""
        Swap avframe* within two frames.

        Parameters
        ----------
        theFrame1: Media_Frame
        theFrame2: Media_Frame

        Returns
        -------
        None

        """
        return _Media.Media_Frame_Swap(*args)

    def Unref(self, *args) -> "void":
        r"""
        Av_frame_unref() wrapper.

        Returns
        -------
        None

        """
        return _Media.Media_Frame_Unref(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_Media_Frame_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _Media.delete_Media_Frame

# Register Media_Frame in _Media:
_Media.Media_Frame_swigregister(Media_Frame)

def Media_Frame_FormatFFmpeg2Occt(*args) -> "Image_Format":
    r"""
    Convert pixel format from ffmpeg (avpixelformat) to occt.

    Parameters
    ----------
    theFormat: int

    Returns
    -------
    Image_Format

    """
    return _Media.Media_Frame_FormatFFmpeg2Occt(*args)

def Media_Frame_FormatOcct2FFmpeg(*args) -> "int":
    r"""
    Convert pixel format from occt to ffmpeg (avpixelformat). returns -1 (av_pix_fmt_none) if undefined.

    Parameters
    ----------
    theFormat: Image_Format

    Returns
    -------
    int

    """
    return _Media.Media_Frame_FormatOcct2FFmpeg(*args)

def Media_Frame_Swap(*args) -> "void":
    r"""
    Swap avframe* within two frames.

    Parameters
    ----------
    theFrame1: Media_Frame
    theFrame2: Media_Frame

    Returns
    -------
    None

    """
    return _Media.Media_Frame_Swap(*args)

class Media_IFrameQueue(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def LockFrame(self, *args) -> "opencascade::handle< Media_Frame >":
        r"""
        Lock the frame, e.g. take ownership on a single (not currently displayed) frame from the queue to perform decoding into.

        Returns
        -------
        opencascade::handle<Media_Frame>

        """
        return _Media.Media_IFrameQueue_LockFrame(self, *args)

    def ReleaseFrame(self, *args) -> "void":
        r"""
        Release previously locked frame, e.g. it can be displayed on the screen.

        Parameters
        ----------
        theFrame: Media_Frame

        Returns
        -------
        None

        """
        return _Media.Media_IFrameQueue_ReleaseFrame(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _Media.delete_Media_IFrameQueue

# Register Media_IFrameQueue in _Media:
_Media.Media_IFrameQueue_swigregister(Media_IFrameQueue)

class Media_Packet(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _Media.Media_Packet_swiginit(self, _Media.new_Media_Packet(*args))

    def ChangeData(self, *args) -> "uint8_t *":
        r"""
        Return data.

        Returns
        -------
        uint8_t *

        """
        return _Media.Media_Packet_ChangeData(self, *args)

    def ChangePacket(self, *args) -> "AVPacket *":
        r"""
        Return packet.

        Returns
        -------
        AVPacket *

        """
        return _Media.Media_Packet_ChangePacket(self, *args)

    def Data(self, *args) -> "uint8_t const *":
        r"""
        Return data.

        Returns
        -------
        uint8_t *

        """
        return _Media.Media_Packet_Data(self, *args)

    def Dts(self, *args) -> "int64_t":
        r"""
        Return decoding timestamp (dts).

        Returns
        -------
        int64_t

        """
        return _Media.Media_Packet_Dts(self, *args)

    def Duration(self, *args) -> "int64_t":
        r"""
        Return duration.

        Returns
        -------
        int64_t

        """
        return _Media.Media_Packet_Duration(self, *args)

    def DurationSeconds(self, *args) -> "double":
        r"""
        Return duration in seconds.

        Returns
        -------
        double

        """
        return _Media.Media_Packet_DurationSeconds(self, *args)

    def IsKeyFrame(self, *args) -> "bool":
        r"""
        Return true for a key frame.

        Returns
        -------
        bool

        """
        return _Media.Media_Packet_IsKeyFrame(self, *args)

    def Packet(self, *args) -> "AVPacket const *":
        r"""
        Return packet.

        Returns
        -------
        AVPacket *

        """
        return _Media.Media_Packet_Packet(self, *args)

    def Pts(self, *args) -> "int64_t":
        r"""
        Return presentation timestamp (pts).

        Returns
        -------
        int64_t

        """
        return _Media.Media_Packet_Pts(self, *args)

    def SetDurationSeconds(self, *args) -> "void":
        r"""
        Set duration in seconds.

        Parameters
        ----------
        theDurationSec: double

        Returns
        -------
        None

        """
        return _Media.Media_Packet_SetDurationSeconds(self, *args)

    def SetKeyFrame(self, *args) -> "void":
        r"""
        Mark as key frame.

        Returns
        -------
        None

        """
        return _Media.Media_Packet_SetKeyFrame(self, *args)

    def Size(self, *args) -> "int":
        r"""
        Return data size.

        Returns
        -------
        int

        """
        return _Media.Media_Packet_Size(self, *args)

    def StreamIndex(self, *args) -> "int":
        r"""
        Return stream index.

        Returns
        -------
        int

        """
        return _Media.Media_Packet_StreamIndex(self, *args)

    def Unref(self, *args) -> "void":
        r"""
        Av_packet_unref() wrapper.

        Returns
        -------
        None

        """
        return _Media.Media_Packet_Unref(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_Media_Packet_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _Media.delete_Media_Packet

# Register Media_Packet in _Media:
_Media.Media_Packet_swigregister(Media_Packet)

class Media_PlayerContext(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Main constructor. note that frame queue is stored as pointer, and it is expected that this context is stored as a class field of frame queue.

        Parameters
        ----------
        theFrameQueue: Media_IFrameQueue *

        Returns
        -------
        None

        """
        _Media.Media_PlayerContext_swiginit(self, _Media.new_Media_PlayerContext(*args))

    @staticmethod
    def DumpFirstFrame(*args) -> "bool":
        r"""
        Dump first video frame. @param thesrcvideo [in] path to the video @param themediainfo [out] video description.

        Parameters
        ----------
        theSrcVideo: TCollection_AsciiString
        theMediaInfo: TCollection_AsciiString

        Returns
        -------
        opencascade::handle<Media_Frame>
        Dump first video frame. @param thesrcvideo [in] path to the video @param theoutimage [in] path to make a screenshot @param themediainfo [out] video description @param themaxsize [in] when positive - downscales image to specified size.

        Parameters
        ----------
        theSrcVideo: TCollection_AsciiString
        theOutImage: TCollection_AsciiString
        theMediaInfo: TCollection_AsciiString
        theMaxSize: int,optional
        	default value is 0

        Returns
        -------
        bool

        """
        return _Media.Media_PlayerContext_DumpFirstFrame(*args)

    def Pause(self, *args) -> "void":
        r"""
        Pause playback.

        Returns
        -------
        None

        """
        return _Media.Media_PlayerContext_Pause(self, *args)

    def PlayPause(self, *args) -> "void":
        r"""
        Pause/pause playback depending on the current state.

        Parameters
        ----------

        Returns
        -------
        theIsPaused: bool
        theProgress: float
        theDuration: float

        """
        return _Media.Media_PlayerContext_PlayPause(self, *args)

    def PlaybackState(self, *args) -> "void":
        r"""
        Return playback state.

        Parameters
        ----------

        Returns
        -------
        theIsPaused: bool
        theProgress: float
        theDuration: float

        """
        return _Media.Media_PlayerContext_PlaybackState(self, *args)

    def Resume(self, *args) -> "void":
        r"""
        Resume playback.

        Returns
        -------
        None

        """
        return _Media.Media_PlayerContext_Resume(self, *args)

    def Seek(self, *args) -> "void":
        r"""
        Seek to specified position.

        Parameters
        ----------
        thePosSec: float

        Returns
        -------
        None

        """
        return _Media.Media_PlayerContext_Seek(self, *args)

    def SetForceRgb(self, *args) -> "void":
        r"""
        Set if queue requires rgb pixel format or can handle also yuv pixel format.

        Parameters
        ----------
        theToForce: bool

        Returns
        -------
        None

        """
        return _Media.Media_PlayerContext_SetForceRgb(self, *args)

    def SetInput(self, *args) -> "void":
        r"""
        Set new input for playback.

        Parameters
        ----------
        theInputPath: TCollection_AsciiString
        theToWait: bool

        Returns
        -------
        None

        """
        return _Media.Media_PlayerContext_SetInput(self, *args)

    def ToForceRgb(self, *args) -> "bool":
        r"""
        Return true if queue requires rgb pixel format or can handle also yuv pixel format; true by default.

        Returns
        -------
        bool

        """
        return _Media.Media_PlayerContext_ToForceRgb(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_Media_PlayerContext_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _Media.delete_Media_PlayerContext

# Register Media_PlayerContext in _Media:
_Media.Media_PlayerContext_swigregister(Media_PlayerContext)

def Media_PlayerContext_DumpFirstFrame(*args) -> "bool":
    r"""
    Dump first video frame. @param thesrcvideo [in] path to the video @param themediainfo [out] video description.

    Parameters
    ----------
    theSrcVideo: TCollection_AsciiString
    theMediaInfo: TCollection_AsciiString

    Returns
    -------
    opencascade::handle<Media_Frame>
    Dump first video frame. @param thesrcvideo [in] path to the video @param theoutimage [in] path to make a screenshot @param themediainfo [out] video description @param themaxsize [in] when positive - downscales image to specified size.

    Parameters
    ----------
    theSrcVideo: TCollection_AsciiString
    theOutImage: TCollection_AsciiString
    theMediaInfo: TCollection_AsciiString
    theMaxSize: int,optional
    	default value is 0

    Returns
    -------
    bool

    """
    return _Media.Media_PlayerContext_DumpFirstFrame(*args)

class Media_Scaler(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _Media.Media_Scaler_swiginit(self, _Media.new_Media_Scaler(*args))

    def Convert(self, *args) -> "bool":
        r"""
        Convert one frame to another.

        Parameters
        ----------
        theSrc: Media_Frame
        theRes: Media_Frame

        Returns
        -------
        bool

        """
        return _Media.Media_Scaler_Convert(self, *args)

    def Init(self, *args) -> "bool":
        r"""
        Sws_getcontext() wrapper - creates conversion context. @param thesrcdims dimensions of input frame @param thesrcformat pixel format (avpixelformat) of input frame @param theresdims dimensions of destination frame @param theresformat pixel format (avpixelformat) of destination frame.

        Parameters
        ----------
        theSrcDims: Graphic3d_Vec2i
        theSrcFormat: int
        theResDims: Graphic3d_Vec2i
        theResFormat: int

        Returns
        -------
        bool

        """
        return _Media.Media_Scaler_Init(self, *args)

    def IsValid(self, *args) -> "bool":
        r"""
        Return true if context was initialized.

        Returns
        -------
        bool

        """
        return _Media.Media_Scaler_IsValid(self, *args)

    def Release(self, *args) -> "void":
        r"""
        Sws_freecontext() wrapper.

        Returns
        -------
        None

        """
        return _Media.Media_Scaler_Release(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_Media_Scaler_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _Media.delete_Media_Scaler

# Register Media_Scaler in _Media:
_Media.Media_Scaler_swigregister(Media_Scaler)

class Media_Timer(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _Media.Media_Timer_swiginit(self, _Media.new_Media_Timer(*args))

    def ElapsedTime(self, *args) -> "Standard_Real":
        r"""
        Return elapsed time in seconds.

        Returns
        -------
        float

        """
        return _Media.Media_Timer_ElapsedTime(self, *args)

    def IsStarted(self, *args) -> "Standard_Boolean":
        r"""
        Return true if timer has been started.

        Returns
        -------
        bool

        """
        return _Media.Media_Timer_IsStarted(self, *args)

    def Pause(self, *args) -> "void":
        r"""
        Pause the timer.

        Returns
        -------
        None

        """
        return _Media.Media_Timer_Pause(self, *args)

    def PlaybackSpeed(self, *args) -> "Standard_Real":
        r"""
        Return playback speed coefficient (1.0 means normal speed).

        Returns
        -------
        float

        """
        return _Media.Media_Timer_PlaybackSpeed(self, *args)

    def Seek(self, *args) -> "void":
        r"""
        Seek the timer to specified position.

        Parameters
        ----------
        theTime: float

        Returns
        -------
        None

        """
        return _Media.Media_Timer_Seek(self, *args)

    def SetPlaybackSpeed(self, *args) -> "void":
        r"""
        Setup playback speed coefficient.

        Parameters
        ----------
        theSpeed: float

        Returns
        -------
        None

        """
        return _Media.Media_Timer_SetPlaybackSpeed(self, *args)

    def Start(self, *args) -> "void":
        r"""
        Start the timer.

        Returns
        -------
        None

        """
        return _Media.Media_Timer_Start(self, *args)

    def Stop(self, *args) -> "void":
        r"""
        Stop the timer.

        Returns
        -------
        None

        """
        return _Media.Media_Timer_Stop(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_Media_Timer_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _Media.delete_Media_Timer

# Register Media_Timer in _Media:
_Media.Media_Timer_swigregister(Media_Timer)








from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.BinMDF import *
from OCC.Core.Message import *
from OCC.Core.TDF import *
from OCC.Core.BinObjMgt import *


class binmdatastd:
	@staticmethod
	def AddDrivers(theDriverTable: BinMDF_ADriverTable, aMsgDrv: Message_Messenger) -> None: ...

class BinMDataStd_AsciiStringDriver(BinMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: BinObjMgt_Persistent, Target: TDF_Attribute, RelocTable: BinObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: BinObjMgt_Persistent, RelocTable: BinObjMgt_SRelocationTable) -> None: ...

class BinMDataStd_BooleanArrayDriver(BinMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: BinObjMgt_Persistent, Target: TDF_Attribute, RelocTable: BinObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: BinObjMgt_Persistent, RelocTable: BinObjMgt_SRelocationTable) -> None: ...

class BinMDataStd_BooleanListDriver(BinMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: BinObjMgt_Persistent, Target: TDF_Attribute, RelocTable: BinObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: BinObjMgt_Persistent, RelocTable: BinObjMgt_SRelocationTable) -> None: ...

class BinMDataStd_ByteArrayDriver(BinMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: BinObjMgt_Persistent, Target: TDF_Attribute, RelocTable: BinObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: BinObjMgt_Persistent, RelocTable: BinObjMgt_SRelocationTable) -> None: ...

class BinMDataStd_ExpressionDriver(BinMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: BinObjMgt_Persistent, Target: TDF_Attribute, RelocTable: BinObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: BinObjMgt_Persistent, RelocTable: BinObjMgt_SRelocationTable) -> None: ...

class BinMDataStd_ExtStringArrayDriver(BinMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: BinObjMgt_Persistent, Target: TDF_Attribute, RelocTable: BinObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: BinObjMgt_Persistent, RelocTable: BinObjMgt_SRelocationTable) -> None: ...

class BinMDataStd_ExtStringListDriver(BinMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: BinObjMgt_Persistent, Target: TDF_Attribute, RelocTable: BinObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: BinObjMgt_Persistent, RelocTable: BinObjMgt_SRelocationTable) -> None: ...

class BinMDataStd_GenericEmptyDriver(BinMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: BinObjMgt_Persistent, Target: TDF_Attribute, RelocTable: BinObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: BinObjMgt_Persistent, RelocTable: BinObjMgt_SRelocationTable) -> None: ...
	def SourceType(self) -> Standard_Type: ...

class BinMDataStd_GenericExtStringDriver(BinMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: BinObjMgt_Persistent, Target: TDF_Attribute, RelocTable: BinObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: BinObjMgt_Persistent, RelocTable: BinObjMgt_SRelocationTable) -> None: ...
	def SourceType(self) -> Standard_Type: ...

class BinMDataStd_IntPackedMapDriver(BinMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: BinObjMgt_Persistent, Target: TDF_Attribute, RelocTable: BinObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: BinObjMgt_Persistent, RelocTable: BinObjMgt_SRelocationTable) -> None: ...

class BinMDataStd_IntegerArrayDriver(BinMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: BinObjMgt_Persistent, Target: TDF_Attribute, RelocTable: BinObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: BinObjMgt_Persistent, RelocTable: BinObjMgt_SRelocationTable) -> None: ...

class BinMDataStd_IntegerDriver(BinMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: BinObjMgt_Persistent, Target: TDF_Attribute, RelocTable: BinObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: BinObjMgt_Persistent, RelocTable: BinObjMgt_SRelocationTable) -> None: ...

class BinMDataStd_IntegerListDriver(BinMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: BinObjMgt_Persistent, Target: TDF_Attribute, RelocTable: BinObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: BinObjMgt_Persistent, RelocTable: BinObjMgt_SRelocationTable) -> None: ...

class BinMDataStd_NamedDataDriver(BinMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: BinObjMgt_Persistent, Target: TDF_Attribute, RelocTable: BinObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: BinObjMgt_Persistent, RelocTable: BinObjMgt_SRelocationTable) -> None: ...

class BinMDataStd_RealArrayDriver(BinMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: BinObjMgt_Persistent, Target: TDF_Attribute, RelocTable: BinObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: BinObjMgt_Persistent, RelocTable: BinObjMgt_SRelocationTable) -> None: ...

class BinMDataStd_RealDriver(BinMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: BinObjMgt_Persistent, Target: TDF_Attribute, RelocTable: BinObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: BinObjMgt_Persistent, RelocTable: BinObjMgt_SRelocationTable) -> None: ...

class BinMDataStd_RealListDriver(BinMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: BinObjMgt_Persistent, Target: TDF_Attribute, RelocTable: BinObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: BinObjMgt_Persistent, RelocTable: BinObjMgt_SRelocationTable) -> None: ...

class BinMDataStd_ReferenceArrayDriver(BinMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: BinObjMgt_Persistent, Target: TDF_Attribute, RelocTable: BinObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: BinObjMgt_Persistent, RelocTable: BinObjMgt_SRelocationTable) -> None: ...

class BinMDataStd_ReferenceListDriver(BinMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: BinObjMgt_Persistent, Target: TDF_Attribute, RelocTable: BinObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: BinObjMgt_Persistent, RelocTable: BinObjMgt_SRelocationTable) -> None: ...

class BinMDataStd_TreeNodeDriver(BinMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: BinObjMgt_Persistent, Target: TDF_Attribute, RelocTable: BinObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: BinObjMgt_Persistent, RelocTable: BinObjMgt_SRelocationTable) -> None: ...

class BinMDataStd_UAttributeDriver(BinMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: BinObjMgt_Persistent, Target: TDF_Attribute, RelocTable: BinObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: BinObjMgt_Persistent, RelocTable: BinObjMgt_SRelocationTable) -> None: ...

class BinMDataStd_VariableDriver(BinMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: BinObjMgt_Persistent, Target: TDF_Attribute, RelocTable: BinObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: BinObjMgt_Persistent, RelocTable: BinObjMgt_SRelocationTable) -> None: ...

# harray1 classes
# harray2 classes
# hsequence classes

binmdatastd_AddDrivers = binmdatastd.AddDrivers
